==> geeklog-1.6.0sr2-jp-1.0a.tar.gz: geeklog-1.6.0sr2-jp-1.0/plugins/staticpages/language/korean.php <==
<?php

###############################################################################
# korean_utf-8.php
# This is the english language page for the Geeklog Static Page Plug-in!
#
# Copyright (C) 2001 Tony Bibbs
# tony@tonybibbs.com
# Tranlated by IvySOHO Ivy(KOMMA Tetsuko/Kim Younghie)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

global $LANG32;

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

$LANG_STATIC = array(
    'newpage' => 'ű',
    'adminhome' => 'ȭ',
    'staticpages' => ' ',
    'staticpageeditor' => '  ',
    'writtenby' => '',
    'date' => '',
    'title' => '',
    'content' => '',
    'hits' => 'ȸǼ',
    'staticpagelist' => '  ',
    'url' => 'URL',
    'edit' => '',
    'lastupdated' => '',
    'pageformat' => ' ',
    'leftrightblocks' => '¿α ֽϴ',
    'blankpage' => 'ü ȭǥ',
    'noblocks' => 'α ϴ',
    'leftblocks' => 'α ֽϴ(α״ ϴ)',
    'addtomenu' => 'α ޴ ߰',
    'label' => '޴̸',
    'nopages' => '  ϴ',
    'save' => '',
    'preview' => '̸',
    'delete' => '',
    'cancel' => '',
    'access_denied' => '˼մϴٸ,  α Ͻñ ٶϴ',
    'access_denied_msg' => 'üũ ϸ ӱ  , ȭ α ȭ ڵ ǥõ˴ϴ.  üũ  ʴ 쿡  ϴ١ ޼ ǥ ˴ϴ',
    'all_html_allowed' => ' HTML  ̿   ֽϴ',
    'results' => '  ˻',
    'author' => '',
    'no_title_or_content' => ' <b> </b>   <b> </b>  ֽñ ٶϴ.',
    'no_such_page_anon' => 'α Ͻñ ٶϴ.',
    'no_page_access_msg' => "   α  ʾҰų Ƹ  Ʈ {$_CONF['site_name']}  ȸ ƴϱ   ϴ.  {$_CONF['site_name']}  <a href=\"{$_CONF['site_url']}/users.php?mode=new\"> ȸ</a> Ͻðų,  ӱ ڷ  Ͻñ ٶϴ",
    'php_msg' => 'PHP: ',
    'php_warn' => '<br' . XHTML . '>:  ɼ ȿϱ Ǹ   ִ PHP ڵ尡 ˴ϴ.    ̿ϴ 쿡 ٽѹ ȭ ׷:Static Page Admin ѡStaticpages. PHP  üũϽñ ٶϴ.  PHP ϴ  (return)  ״ PHP ϱ⡹ 忡 ̿  ֽϴ.  ̿뿡  Ǹ ̽ñ ٶϴ !!',
    'exit_msg' => 'ȸ  : ',
    'exit_info' => 'üũ ϸ ȸ  , α 䱸ȭ ǥõ˴ϴ. üũ  ʴ 쿡  ϴ١  ޼ ǥõ˴ϴ.',
    'deny_msg' => ' ӿ  Ͽϴ.   ̵ Ȥ ǰų, ƴϸ  ų    Դϴ.',
    'stats_headline' => '   10',
    'stats_page_title' => '',
    'stats_hits' => 'ȸǼ',
    'stats_no_hits' => '  ų, ȸڰ ų   Դϴ.',
    'id' => 'ID',
    'duplicate_id' => ' ID  ̹  ǰ ֽϴ. ٸ ID Ͻñ ٶϴ.',
    'instructions' => ' ,    Ӹκ  Ŭ.   ȸ  Ŭ, ο  ۼ  쿡 űۼũ Ŭ.   C Ŭ Ͻñ ٶϴ.',
    'centerblock' => '߽ɿ ǥ: ',
    'centerblock_msg' => 'üũ ϸ ó Ȥ ȭ Ӹ  ߽ɿ ǥõ˴ϴ. ǥô ID з ˴ϴ.',
    'topic' => ': ',
    'position' => 'ǥ: ',
    'all_topics' => '',
    'no_topic' => 'Ȩ',
    'position_top' => ' Ӹκ',
    'position_feat' => 'ָ Ʒκ',
    'position_bottom' => ' Ʒ',
    'position_entire' => ' ü',
    'head_centerblock' => 'Ӹ ǥ',
    'centerblock_no' => 'ƴϿ',
    'centerblock_top' => 'Ӹ',
    'centerblock_feat' => 'ָ',
    'centerblock_bottom' => 'Ʒκ',
    'centerblock_entire' => ' ü',
    'inblock_msg' => 'α׷ ѷ: ',
    'inblock_info' => 'üũ ϸ  ǥõǸ,  ھȿ ϴ.',
    'title_edit' => '',
    'title_copy' => '縦 ۼ',
    'title_display' => ' ǥ',
    'select_php_none' => 'PHP  ʽϴ',
    'select_php_return' => 'PHP մϴ (return)',
    'select_php_free' => ' PHP մϴ',
    'php_not_activated' => "   PHP  ʴ  Ǿ ֽϴ.  ڼ   <a href=\"{$_CONF['site_url']}/docs/english/staticpages.html#php\">  ťƮ </a>  ñ ٶϴ.",
    'printable_format' => 'μ ',
    'copy' => '',
    'limit_results' => ' ˻',
    'search' => '˻',
    'submit' => ''
);

$PLG_staticpages_MESSAGE15 = 'Your comment has been submitted for review and will be published when approved by a moderator.';
$PLG_staticpages_MESSAGE19 = 'Your page has been successfully saved.';
$PLG_staticpages_MESSAGE20 = 'Your page has been successfully deleted.';

// Messages for the plugin upgrade
$PLG_staticpages_MESSAGE3001 = 'Plugin upgrade not supported.';
$PLG_staticpages_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['staticpages'] = array(
    'label' => 'Static Pages',
    'title' => 'Static Pages Configuration'
);

$LANG_confignames['staticpages'] = array(
    'allow_php' => 'Allow PHP?',
    'sort_by' => 'Sort Centerblocks by',
    'sort_menu_by' => 'Sort Menu Entries by',
    'delete_pages' => 'Delete Pages with Owner?',
    'in_block' => 'Wrap Pages in Block?',
    'show_hits' => 'Show Hits?',
    'show_date' => 'Show Date?',
    'filter_html' => 'Filter HTML?',
    'censor' => 'Censor Content?',
    'default_permissions' => 'Page Default Permissions',
    'aftersave' => 'After Saving Page',
    'atom_max_items' => 'Max. Pages in Webservices Feed'
);

$LANG_configsubgroups['staticpages'] = array(
    'sg_main' => 'Main Settings'
);

$LANG_fs['staticpages'] = array(
    'fs_main' => 'Static Pages Main Settings',
    'fs_permissions' => 'Default Permissions'
);

// Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['staticpages'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false),
    2 => array('Date' => 'date', 'Page ID' => 'id', 'Title' => 'title'),
    3 => array('Date' => 'date', 'Page ID' => 'id', 'Title' => 'title', 'Label' => 'label'),
    9 => array('Forward to page' => 'item', 'Display List' => 'list', 'Display Home' => 'home', 'Display Admin' => 'admin'),
    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3)
);

?>

==> geeklog-1.6.1sr2-jp-1.0.tar.gz: geeklog-1.6.1sr2-jp-1.0/plugins/staticpages/language/korean.php <==
<?php

###############################################################################
# korean_utf-8.php
# This is the english language page for the Geeklog Static Page Plug-in!
#
# Copyright (C) 2001 Tony Bibbs
# tony@tonybibbs.com
# Tranlated by IvySOHO Ivy(KOMMA Tetsuko/Kim Younghie)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

global $LANG32;

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

$LANG_STATIC = array(
    'newpage' => 'ű',
    'adminhome' => 'ȭ',
    'staticpages' => ' ',
    'staticpageeditor' => '  ',
    'writtenby' => '',
    'date' => '',
    'title' => '',
    'content' => '',
    'hits' => 'ȸǼ',
    'staticpagelist' => '  ',
    'url' => 'URL',
    'edit' => '',
    'lastupdated' => '',
    'pageformat' => ' ',
    'leftrightblocks' => '¿α ֽϴ',
    'blankpage' => 'ü ȭǥ',
    'noblocks' => 'α ϴ',
    'leftblocks' => 'α ֽϴ(α״ ϴ)',
    'addtomenu' => 'α ޴ ߰',
    'label' => '޴̸',
    'nopages' => '  ϴ',
    'save' => '',
    'preview' => '̸',
    'delete' => '',
    'cancel' => '',
    'access_denied' => '˼մϴٸ,  α Ͻñ ٶϴ',
    'access_denied_msg' => 'üũ ϸ ӱ  , ȭ α ȭ ڵ ǥõ˴ϴ.  üũ  ʴ 쿡  ϴ١ ޼ ǥ ˴ϴ',
    'all_html_allowed' => ' HTML  ̿   ֽϴ',
    'results' => '  ˻',
    'author' => '',
    'no_title_or_content' => ' <b> </b>   <b> </b>  ֽñ ٶϴ.',
    'no_such_page_anon' => 'α Ͻñ ٶϴ.',
    'no_page_access_msg' => "   α  ʾҰų Ƹ  Ʈ {$_CONF['site_name']}  ȸ ƴϱ   ϴ.  {$_CONF['site_name']}  <a href=\"{$_CONF['site_url']}/users.php?mode=new\"> ȸ</a> Ͻðų,  ӱ ڷ  Ͻñ ٶϴ",
    'php_msg' => 'PHP: ',
    'php_warn' => '<br' . XHTML . '>:  ɼ ȿϱ Ǹ   ִ PHP ڵ尡 ˴ϴ.    ̿ϴ 쿡 ٽѹ ȭ ׷:Static Page Admin ѡStaticpages. PHP  üũϽñ ٶϴ.  PHP ϴ  (return)  ״ PHP ϱ⡹ 忡 ̿  ֽϴ.  ̿뿡  Ǹ ̽ñ ٶϴ !!',
    'exit_msg' => 'ȸ  : ',
    'exit_info' => 'üũ ϸ ȸ  , α 䱸ȭ ǥõ˴ϴ. üũ  ʴ 쿡  ϴ١  ޼ ǥõ˴ϴ.',
    'deny_msg' => ' ӿ  Ͽϴ.   ̵ Ȥ ǰų, ƴϸ  ų    Դϴ.',
    'stats_headline' => '   10',
    'stats_page_title' => '',
    'stats_hits' => 'ȸǼ',
    'stats_no_hits' => '  ų, ȸڰ ų   Դϴ.',
    'id' => 'ID',
    'duplicate_id' => ' ID  ̹  ǰ ֽϴ. ٸ ID Ͻñ ٶϴ.',
    'instructions' => ' ,    Ӹκ  Ŭ.   ȸ  Ŭ, ο  ۼ  쿡 űۼũ Ŭ.   C Ŭ Ͻñ ٶϴ.',
    'centerblock' => '߽ɿ ǥ: ',
    'centerblock_msg' => 'üũ ϸ ó Ȥ ȭ Ӹ  ߽ɿ ǥõ˴ϴ. ǥô ID з ˴ϴ.',
    'topic' => ': ',
    'position' => 'ǥ: ',
    'all_topics' => '',
    'no_topic' => 'Ȩ',
    'position_top' => ' Ӹκ',
    'position_feat' => 'ָ Ʒκ',
    'position_bottom' => ' Ʒ',
    'position_entire' => ' ü',
    'head_centerblock' => 'Ӹ ǥ',
    'centerblock_no' => 'ƴϿ',
    'centerblock_top' => 'Ӹ',
    'centerblock_feat' => 'ָ',
    'centerblock_bottom' => 'Ʒκ',
    'centerblock_entire' => ' ü',
    'inblock_msg' => 'α׷ ѷ: ',
    'inblock_info' => 'üũ ϸ  ǥõǸ,  ھȿ ϴ.',
    'title_edit' => '',
    'title_copy' => '縦 ۼ',
    'title_display' => ' ǥ',
    'select_php_none' => 'PHP  ʽϴ',
    'select_php_return' => 'PHP մϴ (return)',
    'select_php_free' => ' PHP մϴ',
    'php_not_activated' => "   PHP  ʴ  Ǿ ֽϴ.  ڼ   <a href=\"{$_CONF['site_url']}/docs/english/staticpages.html#php\">  ťƮ </a>  ñ ٶϴ.",
    'printable_format' => 'μ ',
    'copy' => '',
    'limit_results' => ' ˻',
    'search' => '˻',
    'submit' => '',
    'no_new_pages' => 'No new pages',
    'pages' => 'Pages'
);

$PLG_staticpages_MESSAGE15 = 'Your comment has been submitted for review and will be published when approved by a moderator.';
$PLG_staticpages_MESSAGE19 = 'Your page has been successfully saved.';
$PLG_staticpages_MESSAGE20 = 'Your page has been successfully deleted.';

// Messages for the plugin upgrade
$PLG_staticpages_MESSAGE3001 = 'Plugin upgrade not supported.';
$PLG_staticpages_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['staticpages'] = array(
    'label' => 'Static Pages',
    'title' => 'Static Pages Configuration'
);

$LANG_confignames['staticpages'] = array(
    'allow_php' => 'Allow PHP?',
    'sort_by' => 'Sort Centerblocks by',
    'sort_menu_by' => 'Sort Menu Entries by',
    'delete_pages' => 'Delete Pages with Owner?',
    'in_block' => 'Wrap Pages in Block?',
    'show_hits' => 'Show Hits?',
    'show_date' => 'Show Date?',
    'filter_html' => 'Filter HTML?',
    'censor' => 'Censor Content?',
    'default_permissions' => 'Page Default Permissions',
    'aftersave' => 'After Saving Page',
    'atom_max_items' => 'Max. Pages in Webservices Feed',
    'meta_tags' => 'Enable Meta Tags',
    'newstaticpagesinterval' => 'New Static Page Interval',
    'hidenewstaticpages' => 'Hide New Static Pages',
    'title_trim_length' => 'Title Trim Length',
    'includecenterblocks' => 'Include Center Block Static Pages',
    'includephp' => 'Include Static Pages with PHP',
    'includesearch' => 'Enable Static Pages in Search',
    'includesearchcenterblocks' => 'Include Center Block Static Pages',
    'includesearchphp' => 'Include Static Pages with PHP'
);

$LANG_configsubgroups['staticpages'] = array(
    'sg_main' => 'Main Settings'
);

$LANG_fs['staticpages'] = array(
    'fs_main' => 'Static Pages Main Settings',
    'fs_whatsnew' => 'What\'s New Block',
    'fs_search' => 'Search Results',
    'fs_permissions' => 'Default Permissions'
);

// Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['staticpages'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false),
    2 => array('Date' => 'date', 'Page ID' => 'id', 'Title' => 'title'),
    3 => array('Date' => 'date', 'Page ID' => 'id', 'Title' => 'title', 'Label' => 'label'),
    9 => array('Forward to page' => 'item', 'Display List' => 'list', 'Display Home' => 'home', 'Display Admin' => 'admin'),
    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3)
);

?>
